Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(19)

Unified Diff: include/v8.h

Issue 2571743002: [serializer] API to re-use global proxy in v8::Context::FromSnapshot. (Closed)
Patch Set: Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/api.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/v8.h
diff --git a/include/v8.h b/include/v8.h
index 6d7f5cab13098a1974dd3abf5c507f7f504888bc..3097346d219180076d81e8cf3b5e1231996c62d7 100644
--- a/include/v8.h
+++ b/include/v8.h
@@ -7895,8 +7895,8 @@ class V8_EXPORT Context {
/**
* Create a new context from a (non-default) context snapshot. There
* is no way to provide a global template or global proxy since the
* context snapshot already contains a global proxy.
*
* \param isolate See v8::Context::New.
*
@@ -7904,11 +7904,14 @@ class V8_EXPORT Context {
* deserialize from. Use v8::Context::New for the default snapshot.
*
* \param extensions See v8::Context::New.
+ *
+ * \param global_object See v8::Context::New.
*/
static MaybeLocal<Context> FromSnapshot(
Isolate* isolate, size_t context_snapshot_index,
- ExtensionConfiguration* extensions = nullptr);
+ ExtensionConfiguration* extensions = nullptr,
+ MaybeLocal<Value> global_object = MaybeLocal<Value>());
/**
* Returns an global object that isn't backed by an actual context.
« no previous file with comments | « no previous file | src/api.cc » ('j') | no next file with comments »
@@ -7895,8 +7895,8 @@ class V8_EXPORT Context {
/**
* Create a new context from a (non-default) context snapshot. There
- * is no way to provide a global template or global proxy since the
- * context snapshot already contains a global proxy.
+ * is no way to provide a global object template since we do not create
+ * a new global object from template, but we can reuse a global object.
*
* \param isolate See v8::Context::New.

Powered by Google App Engine
This is Rietveld 408576698